# eric7.Preferences.ConfigurationPages.MicroPythonPage

Module implementing the MicroPython configuration page.

### Global Attributes

QChart

### Classes

MicroPythonPage | Class implementing the MicroPython configuration page.

### Functions

create | Module function to create the configuration page.

## MicroPythonPage

Class implementing the MicroPython configuration page.

### Derived from

ConfigurationPageBase, Ui_MicroPythonPage

### Class Attributes

None

### Class Methods

None

### Methods

MicroPythonPage | Constructor
on_apShowPasswordButton_clicked | Private slot to show or hide the WiFi Access Point password.
on_mpyCrossInstallButton_clicked | Private slot to install the 'mpy-cross' compiler.
on_mpyCrossPicker_textChanged | Private slot to handle a change of the selected 'mpy-cross' compiler.
on_showPasswordButton_clicked | Private slot to show or hide the WiFi client password.
save | Public slot to save the MicroPython configuration.

### Static Methods

None

#### MicroPythonPage (Constructor)

MicroPythonPage()

Constructor

#### MicroPythonPage.on_apShowPasswordButton_clicked

on_apShowPasswordButton_clicked(checked)

Private slot to show or hide the WiFi Access Point password.

checked (bool)
  state of the button

#### MicroPythonPage.on_mpyCrossInstallButton_clicked

on_mpyCrossInstallButton_clicked()

Private slot to install the 'mpy-cross' compiler.

#### MicroPythonPage.on_mpyCrossPicker_textChanged

on_mpyCrossPicker_textChanged(mpycrossPath)

Private slot to handle a change of the selected 'mpy-cross' compiler.

mpycrossPath (str)
  entered path of the 'mpy-cross' compiler

#### MicroPythonPage.on_showPasswordButton_clicked

on_showPasswordButton_clicked(checked)

Private slot to show or hide the WiFi client password.

checked (bool)
  state of the button

#### MicroPythonPage.save

save()

Public slot to save the MicroPython configuration.

Up

## create

create(_dlg)

Module function to create the configuration page.

_dlg (ConfigurationDialog)
  reference to the configuration dialog (unused)

Return:
  reference to the instantiated page

Return Type:
  ConfigurationPageBase

Up